/*!
 * Q3Stats JS app | Copyright 2017 by Tomek Wójcik | MIT License
 * https://git.bthlabs.pl/q3stats
 */

import React from "react";
import ReactDOM from "react-dom";
import {Router, Route, hashHistory} from "react-router";
import {Provider} from "react-redux";
import "whatwg-fetch";

import AppWindow from "./AppWindow";
import SessionsView from "./views/SessionsView";
import PlayersView from "./views/PlayersView";
import PlayerGameView from "./views/PlayerGameView";
import PlayerStatsView from "./views/PlayerStatsView";
import ErrorView from "./views/ErrorView";
import reactStore from "./store";

window.addEventListener("load", function () {
  ReactDOM.render(
    <Provider store={reactStore}>
      <Router history={hashHistory}>
        <Route path="/" component={AppWindow}>
          <Route path="/sessions/" component={SessionsView}>
            <Route path="/sessions/:day" component={SessionsView} />
          </Route>
          <Route path="/players/:player/game/:game" component={PlayerGameView} />
          <Route path="/players/" component={PlayersView}>
            <Route path="/players/:player" component={PlayerStatsView} />
          </Route>
          <Route path="/error/" component={ErrorView}>
            <Route path="/error/:errorCode" component={ErrorView} />
          </Route>
        </Route>
      </Router>
    </Provider>,
    document.getElementById("main")
  );
});
