/**
 * Copyright (c) 2017 Tomek Wójcik <tomek@bthlabs.pl>
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to
 * deal in the Software without restriction, including without limitation the
 * rights to use, copy, modify, merge, publish, distribute, sublicense, and/or
 * sell copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
 * FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS
 * IN THE SOFTWARE.
 */

import React from "react";

import BaseView from "../lib/BaseView";
import ChartComponent from "../components/ChartComponent";
import ContainerComponent from "../components/ContainerComponent";
import LoaderComponent from "../components/LoaderComponent";

class TopPlayersTableView extends React.Component {
  render () {
    return (
      <table className="table table-striped table-bordered table-hover">
        <thead>
            <tr>
                <th>Player</th>
                <th>{this.props.scoreColumnTitle}</th>
            </tr>
        </thead>

        <tbody>
          {(this.props.scores.length == 0) &&
            <tr>
              <td colSpan="2"><strong>No stats :(</strong></td>
            </tr>
          }

          {this.props.scores.map(function (item, index) {
            return (
              <tr key={index}>
                <td>{item[0]}</td>
                <td>{item[1]}</td>
              </tr>
            );
          })}
        </tbody>
      </table>
    );
  }
}

TopPlayersTableView.propTypes = {
  scoreColumnTitle: React.PropTypes.string.isRequired,
  scores: React.PropTypes.array
};

class DashboardView extends BaseView {
  constructor (props) {
    super(props);

    this.chartConfig = {
      "chart": {
        "type": "column"
      },
      "title": {
        "text": "Scores by map and player"
      },
      "credits": {
        "enabled": false
      },
      "yAxis": {
        "min": -10,
        "title": {
            "text": "Score"
        }
      },
      "plotOptions": {
        "column": {
          "pointPadding": 0.2,
          "borderWidth": 0
        }
      }
    };

    this.state = {
      ready: false,
      day: "",
      emosOfTheMonth: [],
      fraggersOfTheMonth: [],
      categories: null,
      series: []
    };
  }
  componentDidMount () {
    this.fetch("/api/v1/dashboard").then((data) => {
      this.setState({
        ready: true,
        day: data.day,
        emosOfTheMonth: data.eotm,
        fraggersOfTheMonth: data.fotm
      });

      this.loadChartData();
    });
  }
  loadChartData () {
    this.fetch("/api/v1/charts/day/" + this.state.day).then((data) => {
      this.setState({
        categories: data.maps,
        series: data.scores
      });
    });
  }
  render () {
    return (
      <ContainerComponent>
        <h2>Dashboard</h2>

        <ChartComponent
          config={this.chartConfig}
          categories={this.state.categories}
          series={this.state.series}
          subtitle={this.state.day} />

        <div className="row">
          <div className="col-sm-6">
            <h2>Fraggers of the month</h2>

            <TopPlayersTableView
              scoreColumnTitle="Frags"
              scores={this.state.fraggersOfTheMonth} />
          </div>

          <div className="col-sm-6">
            <h2>Emos of the month</h2>

            <TopPlayersTableView
              scoreColumnTitle="Suicides"
              scores={this.state.emosOfTheMonth} />
          </div>
        </div>

        <LoaderComponent visible={!this.state.ready} />
      </ContainerComponent>
    );
  }
}

export default DashboardView;
