/**
 * Copyright (c) 2017 Tomek Wójcik <tomek@bthlabs.pl>
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to
 * deal in the Software without restriction, including without limitation the
 * rights to use, copy, modify, merge, publish, distribute, sublicense, and/or
 * sell copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
 * FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS
 * IN THE SOFTWARE.
 */

import ClassName from "classnames";
import React from "react";
import {Link} from "react-router";

import BaseView from "../lib/BaseView";
import ContainerComponent from "../components/ContainerComponent";
import LoaderComponent from "../components/LoaderComponent";
import PlayerStatsView from "./PlayerStatsView";

class PlayerLinkComponent extends React.Component {
  render () {
    let className = ClassName({
      active: this.props.active
    });

    return (
      <li className={className}>
        <Link to={"/players/" + this.props.player}>{this.props.player}</Link>
      </li>
    );
  }
}

PlayerLinkComponent.propTypes = {
  active: React.PropTypes.bool.isRequired,
  player: React.PropTypes.string.isRequired
};

class PlayersView extends BaseView {
  constructor (props) {
    super(props);

    this.state = {
      ready: false,
      players: []
    };
  }
  componentDidMount () {
    this.fetch("/api/v1/players").then((data) => {
      this.setState({
        ready: true,
        players: data.players
      });
    });
  }
  render () {
    return (
      <ContainerComponent>
        <div className="row">
          <div className="col-sm-3">
            <h2>Players</h2>
            <ul className="nav nav-pills nav-stacked">
              {this.state.players.map((item, index) => {
                return (
                  <PlayerLinkComponent
                    key={index}
                    active={(this.props.params.player == item)}
                    player={item} />
                );
              })}
            </ul>
          </div>

          <div className="col-sm-9">
            {this.props.children ||
              <div>
                <h2>Players</h2>
                <p className="lead">Choose a player from the list to see their stats.</p>
              </div>
            }
          </div>
        </div>

        <LoaderComponent visible={!this.state.ready} />
      </ContainerComponent>
    );
  }
}

export default PlayersView;
